@@ -48,7 +48,7 @@ def pep518_wheelhouse(tmpdir_factory):
     return str(wheelhouse)
 
 
-@pytest.fixture
+@pytest.fixture()
 def pep518(pep518_wheelhouse, monkeypatch):
     monkeypatch.setenv("PIP_FIND_LINKS", pep518_wheelhouse)
     monkeypatch.setenv("PIP_NO_INDEX", "true")
