@@ -70,7 +70,7 @@ def test_hello_sdist():
 
 def test_hello_wheel():
     expected_content = [
-        "hello/_hello%s" % get_ext_suffix(),
+        f"hello/_hello{get_ext_suffix()}",
         "hello/__init__.py",
         "hello/__main__.py",
         "hello/world.py",
@@ -110,7 +110,6 @@ def test_hello_wheel():
 @pytest.mark.parametrize("dry_run", ["with-dry-run", "without-dry-run"])
 def test_hello_clean(dry_run, capfd):
     with push_dir():
-
         dry_run = dry_run == "with-dry-run"
 
         @project_setup_py_test("hello-cpp", ["build"], ret=True)
@@ -148,7 +147,6 @@ def test_hello_clean(dry_run, capfd):
 
 def test_hello_cleans(capfd, caplog):
     with push_dir():
-
         tmp_dir = _tmpdir("test_hello_cleans")
 
         _copy_dir(tmp_dir, os.path.join(SAMPLES_DIR, "hello-cpp"))
@@ -178,7 +176,7 @@ def test_hello_cleans(capfd, caplog):
         assert "running clean" in msg
 
 
-@pytest.mark.deprecated
+@pytest.mark.deprecated()
 @project_setup_py_test("hello-cpp", ["develop"])
 def test_hello_develop():
     for expected_file in [
@@ -193,7 +191,7 @@ def test_hello_develop():
         "hello/CMakeLists.txt",
         # These files are "generated" by CMake and
         # are copied from CMAKE_INSTALL_DIR
-        "hello/_hello%s" % get_ext_suffix(),
+        f"hello/_hello{get_ext_suffix()}",
         "hello/world.py",
         "helloModule.py",
     ]:
