@@ -9,14 +9,16 @@ HELLO_PEP518 = os.path.join(DIR, "samples/hello-pep518")
 BASE = os.path.dirname(DIR)
 
 
-@pytest.mark.isolated
+@pytest.mark.isolated()
 @pytest.mark.skipif(sys.platform.startswith("cygwin"), reason="Needs release of scikit-build to make cmake work")
-def test_pep518(pep518):
+@pytest.mark.usefixtures("pep518")
+def test_pep518():
     subprocess.run([sys.executable, "-m", "build", "--wheel"], cwd=HELLO_PEP518, check=True)
 
 
-@pytest.mark.isolated
+@pytest.mark.isolated()
 @pytest.mark.skipif(sys.platform.startswith("cygwin"), reason="Needs release of scikit-build to make cmake work")
-def test_dual_pep518(pep518):
+@pytest.mark.usefixtures("pep518")
+def test_dual_pep518():
     subprocess.run([sys.executable, "-m", "build", "--wheel"], cwd=HELLO_PEP518, check=True)
     subprocess.run([sys.executable, "-m", "build", "--wheel"], cwd=HELLO_PEP518, check=True)
