@@ -40,7 +40,6 @@ def test_write_compiler_test_file():
 
 
 def test_cxx_compiler():
-
     # Create a unique subdirectory 'foo' that is expected to be removed.
     test_build_folder = os.path.join(test_folder, "build", "foo")
     mkdir_p(test_build_folder)
@@ -62,7 +61,7 @@ def test_cxx_compiler():
 @pytest.mark.skipif(
     platform.system().lower() in ["darwin", "windows"], reason="no fortran compiler is available by default"
 )
-@pytest.mark.fortran
+@pytest.mark.fortran()
 def test_fortran_compiler():
     generator = skbuild_platform.get_best_generator(languages=["Fortran"])
     # TODO: this isn't a true unit test.  It depends on the test
@@ -95,7 +94,7 @@ def test_known_platform(supported_platform, mocker):
         "os400": "BSD",
         "cygwin": "Cygwin",
     }
-    expected_platform_classname = "%sPlatform" % platforms[supported_platform]
+    expected_platform_classname = f"{platforms[supported_platform]}Platform"
     assert get_platform().__class__.__name__ == expected_platform_classname
 
 
