@@ -35,7 +35,6 @@ from . import (
 
 @pytest.mark.parametrize("distribution_type", ["unknown", "py_modules", "packages", "skbuild"])
 def test_distribution_is_pure(distribution_type, tmpdir):
-
     skbuild_setup_kwargs = {}
 
     if distribution_type == "unknown":
@@ -74,7 +73,6 @@ def test_distribution_is_pure(distribution_type, tmpdir):
         original_write_test_cmakelist([])
 
     with patch.object(type(platform), "write_test_cmakelist", new=write_test_cmakelist_no_languages):
-
         with push_dir(str(tmpdir)), push_argv(["setup.py", "build"]):
             distribution = skbuild_setup(
                 name="test",
@@ -124,7 +122,7 @@ def test_cmake_args_keyword(cmake_args, capfd):
         )
     )
 
-    with execute_setup_py(tmp_dir, ["build"] + cmake_args, disable_languages_test=True):
+    with execute_setup_py(tmp_dir, ["build", *cmake_args], disable_languages_test=True):
         pass
 
     out, _ = capfd.readouterr()
@@ -138,16 +136,15 @@ def test_cmake_args_keyword(cmake_args, capfd):
 
 
 @pytest.mark.parametrize(
-    "cmake_install_dir, expected_failed, error_code_type",
-    (
+    ("cmake_install_dir", "expected_failed", "error_code_type"),
+    [
         (None, True, str),
         ("", True, str),
         (str(py.path.local.get_temproot().join("scikit-build")), True, SKBuildError),
         ("banana", False, str),
-    ),
+    ],
 )
 def test_cmake_install_dir_keyword(cmake_install_dir, expected_failed, error_code_type, capsys, caplog):
-
     # -------------------------------------------------------------------------
     # "SOURCE" tree layout:
     #
@@ -176,7 +173,7 @@ def test_cmake_install_dir_keyword(cmake_install_dir, expected_failed, error_cod
 
     tmp_dir.join("setup.py").write(
         textwrap.dedent(
-            """
+            f"""
         from skbuild import setup
         setup(
             name="test_cmake_install_dir",
@@ -187,9 +184,7 @@ def test_cmake_install_dir_keyword(cmake_install_dir, expected_failed, error_cod
             packages=['apple', 'banana'],
             {setup_kwarg}
         )
-        """.format(
-                setup_kwarg=setup_kwarg
-            )
+        """
         )
     )
 
@@ -225,11 +220,11 @@ def test_cmake_install_dir_keyword(cmake_install_dir, expected_failed, error_cod
     assert failed == expected_failed
     if failed:
         if error_code_type == str:
-            assert message == "error: package directory " "'{}' does not exist".format(
+            assert message == "error: package directory '{}' does not exist".format(
                 os.path.join(CMAKE_INSTALL_DIR(), "banana")
             )
         else:
-            assert message.strip().startswith("setup parameter 'cmake_install_dir' " "is set to an absolute path.")
+            assert message.strip().startswith("setup parameter 'cmake_install_dir' is set to an absolute path.")
     else:
         init_py = to_platform_path(f"{CMAKE_INSTALL_DIR()}/banana/__init__.py")
         assert f"copying {init_py}" in out
@@ -241,7 +236,7 @@ def test_cmake_with_sdist_keyword(cmake_with_sdist, capfd):
 
     tmp_dir.join("setup.py").write(
         textwrap.dedent(
-            """
+            f"""
         from skbuild import setup
         setup(
             name="cmake_with_sdist_keyword",
@@ -251,9 +246,7 @@ def test_cmake_with_sdist_keyword(cmake_with_sdist, capfd):
             license="MIT",
             cmake_with_sdist={cmake_with_sdist}
         )
-        """.format(
-                cmake_with_sdist=cmake_with_sdist
-            )
+        """
         )
     )
     tmp_dir.join("CMakeLists.txt").write(
@@ -321,7 +314,7 @@ def test_cmake_minimum_required_version_keyword():
         assert "CMake version 99.98.97 or higher is required." in message
 
 
-@pytest.mark.deprecated
+@pytest.mark.deprecated()
 @pytest.mark.filterwarnings("ignore:setuptools.installer is deprecated:Warning")
 @pytest.mark.skipif(
     os.environ.get("CONDA_BUILD", "0") == "1",
@@ -333,7 +326,6 @@ def test_cmake_minimum_required_version_keyword():
     sys.platform.startswith("cygwin"), strict=False, reason="Cygwin needs a release of scikit-build first"
 )
 def test_setup_requires_keyword_include_cmake(mocker, capsys):
-
     mock_setup = mocker.patch("skbuild.setuptools_wrap.setuptools.setup")
 
     tmp_dir = _tmpdir("setup_requires_keyword_include_cmake")
@@ -380,9 +372,8 @@ def test_setup_requires_keyword_include_cmake(mocker, capsys):
             assert cmake.__file__.lower().startswith(str(tmp_dir).lower())
 
 
-@pytest.mark.parametrize("distribution_type", ("pure", "skbuild"))
+@pytest.mark.parametrize("distribution_type", ["pure", "skbuild"])
 def test_script_keyword(distribution_type, capsys, caplog):
-
     # -------------------------------------------------------------------------
     #
     # "SOURCE" tree layout for "pure" distribution:
@@ -444,7 +435,7 @@ def test_script_keyword(distribution_type, capsys, caplog):
         )
 
         messages = [
-            "copying {}/{}.py -> " "{}/setuptools/scripts-".format(CMAKE_INSTALL_DIR(), module, SKBUILD_DIR())
+            f"copying {CMAKE_INSTALL_DIR()}/{module}.py -> {SKBUILD_DIR()}/setuptools/scripts-"
             for module in ["foo", "bar"]
         ]
 
@@ -452,9 +443,7 @@ def test_script_keyword(distribution_type, capsys, caplog):
         tmp_dir.join("foo.py").write("# foo.py")
         tmp_dir.join("bar.py").write("# bar.py")
 
-        messages = [
-            "copying {}.py -> " "{}/setuptools/scripts-".format(module, SKBUILD_DIR()) for module in ["foo", "bar"]
-        ]
+        messages = [f"copying {module}.py -> {SKBUILD_DIR()}/setuptools/scripts-" for module in ["foo", "bar"]]
 
     with execute_setup_py(tmp_dir, ["build"], disable_languages_test=True):
         pass
@@ -465,9 +454,8 @@ def test_script_keyword(distribution_type, capsys, caplog):
         assert to_platform_path(message) in out
 
 
-@pytest.mark.parametrize("distribution_type", ("pure", "skbuild"))
+@pytest.mark.parametrize("distribution_type", ["pure", "skbuild"])
 def test_py_modules_keyword(distribution_type, capsys, caplog):
-
     # -------------------------------------------------------------------------
     #
     # "SOURCE" tree layout for "pure" distribution:
@@ -528,15 +516,14 @@ def test_py_modules_keyword(distribution_type, capsys, caplog):
         )
 
         messages = [
-            "copying {}/{}.py -> " "{}/setuptools/lib".format(CMAKE_INSTALL_DIR(), module, SKBUILD_DIR())
-            for module in ["foo", "bar"]
+            f"copying {CMAKE_INSTALL_DIR()}/{module}.py -> {SKBUILD_DIR()}/setuptools/lib" for module in ["foo", "bar"]
         ]
 
     elif distribution_type == "pure":
         tmp_dir.join("foo.py").write("# foo.py")
         tmp_dir.join("bar.py").write("# bar.py")
 
-        messages = ["copying {}.py -> " "{}/setuptools/lib".format(module, SKBUILD_DIR()) for module in ["foo", "bar"]]
+        messages = [f"copying {module}.py -> {SKBUILD_DIR()}/setuptools/lib" for module in ["foo", "bar"]]
 
     with execute_setup_py(tmp_dir, ["build"], disable_languages_test=True):
         pass
@@ -548,7 +535,7 @@ def test_py_modules_keyword(distribution_type, capsys, caplog):
 
 
 @pytest.mark.parametrize(
-    "package_parts, module_file, expected",
+    ("package_parts", "module_file", "expected"),
     [
         ([], "", ""),
         ([""], "file.py", "file.py"),
@@ -567,7 +554,7 @@ def test_strip_package(package_parts, module_file, expected):
     assert strip_package(package_parts, module_file) == expected
 
 
-@pytest.mark.parametrize("has_cmake_package", [0, 1])  # noqa: C901
+@pytest.mark.parametrize("has_cmake_package", [0, 1])
 @pytest.mark.parametrize("has_cmake_module", [0, 1])
 @pytest.mark.parametrize("has_hybrid_package", [0, 1])
 @pytest.mark.parametrize("has_pure_package", [0, 1])
@@ -816,7 +803,7 @@ def test_setup_inputs(
     # Commented paths are the one expected to be installed by CMake. For
     # this reason, corresponding files should NOT be created in the source
     # tree.
-    for (_type, path) in select_paths(
+    for _type, path in select_paths(
         [
             # ('c', 'cmake/__init__.py'),
             # ('c', 'cmake/cmake.py'),
@@ -858,7 +845,6 @@ def test_setup_inputs(
         )
 
     with execute_setup_py(tmp_dir, ["build"], disable_languages_test=True):
-
         assert mock_setup.call_count == 1
         setup_kw = mock_setup.call_args[1]
 
@@ -948,7 +934,6 @@ def test_setup_inputs(
 
 @pytest.mark.parametrize("with_cmake_source_dir", [0, 1])
 def test_cmake_install_into_pure_package(with_cmake_source_dir, capsys, caplog):
-
     # -------------------------------------------------------------------------
     # "SOURCE" tree layout:
     #
@@ -999,7 +984,7 @@ def test_cmake_install_into_pure_package(with_cmake_source_dir, capsys, caplog):
 
     tmp_dir.join("setup.py").write(
         textwrap.dedent(
-            """
+            f"""
         from skbuild import setup
         setup(
             name="test_py_modules_keyword",
@@ -1011,9 +996,7 @@ def test_cmake_install_into_pure_package(with_cmake_source_dir, capsys, caplog):
             cmake_install_dir='fruits',
             cmake_source_dir='{cmake_source_dir}',
         )
-        """.format(
-                cmake_source_dir=cmake_source_dir
-            )
+        """
         )
     )
 
@@ -1049,7 +1032,7 @@ def test_cmake_install_into_pure_package(with_cmake_source_dir, capsys, caplog):
         pass
 
     messages = [
-        "copying {}/{} -> " "{}/setuptools/lib".format(CMAKE_INSTALL_DIR(), module, SKBUILD_DIR())
+        f"copying {CMAKE_INSTALL_DIR()}/{module} -> {SKBUILD_DIR()}/setuptools/lib"
         for module in [
             "fruits/__init__.py",
             "fruits/apple.py",
@@ -1067,7 +1050,6 @@ def test_cmake_install_into_pure_package(with_cmake_source_dir, capsys, caplog):
 
 @pytest.mark.parametrize("zip_safe", [None, False, True])
 def test_zip_safe_default(zip_safe, mocker):
-
     mock_setup = mocker.patch("skbuild.setuptools_wrap.setuptools.setup")
 
     tmp_dir = _tmpdir("zip_safe_default")
@@ -1078,7 +1060,7 @@ def test_zip_safe_default(zip_safe, mocker):
 
     tmp_dir.join("setup.py").write(
         textwrap.dedent(
-            """
+            f"""
         from skbuild import setup
         setup(
             name="zip_safe_default",
@@ -1088,9 +1070,7 @@ def test_zip_safe_default(zip_safe, mocker):
             license="MIT",
             {setup_kwarg}
         )
-        """.format(
-                setup_kwarg=setup_kwarg
-            )
+        """
         )
     )
     tmp_dir.join("CMakeLists.txt").write(
